/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "PerforceLabel.h"
#import "PerforceActionLabel.h"
#import "AppController.h"
#import "ReadOnlyEditorController.h"
#import "PerforceActionSync.h"
#import "MessageDefs.h"
#import "AppUtils.h"

@implementation PerforceLabel

- (id)  initWithName: (NSString*) labelName
        withDate: (NSString*) labelDate
        withDesc: (NSString*) labelDesc;
{
    self = [super init];

    fName			= [labelName copy];
    fDate			= [labelDate copy];
    fDescription	= [labelDesc copy];
    
    return self;
}

- (void) dealloc
{
    [fName release];
    [fDate release];
    [fDescription release];
	
	[super dealloc];
}

- (NSString*) getLabelName
{
    return fName;
}

- (NSString*) getLabelDate
{
    return fDate;
}

- (NSString*) getLabelDescription
{
    return fDescription;
}

- (NSComparisonResult) comparegetLabelNameAscending: (PerforceLabel*) rhs
{
	return [fName compare:rhs->fName];
}

- (NSComparisonResult) comparegetLabelNameDescending: (PerforceLabel*) rhs
{
	return [rhs->fName compare:fName];
}

- (NSComparisonResult) comparegetLabelDateAscending: (PerforceLabel*) rhs
{
	return [fDate compare:rhs->fDate];
}

- (NSComparisonResult) comparegetLabelDateDescending: (PerforceLabel*) rhs
{
	return [rhs->fDate compare:fDate];
}

- (NSComparisonResult) comparegetLabelDescriptionAscending: (PerforceLabel*) rhs
{
	return [fDescription compare:rhs->fDescription];
}

- (NSComparisonResult) comparegetLabelDescriptionDescending: (PerforceLabel*) rhs
{
	return [rhs->fDescription compare:fDescription];
}

// The enablement
- (BOOL) canEdit
{
	return YES;
}

- (BOOL) canDescribe
{
	return YES;
}

- (BOOL) canDelete
{
	return YES;
}

- (BOOL) canSyncTo
{
	return YES;
}

// The actions
- (void) doEdit
{
	[PerforceActionLabelGet defaultRunFor:[NSApp delegate] selector:@selector(resultFromPerforceLabelOut:) identifier:fName];
}

- (void) doDescribe
{
	[PerforceActionLabelGet defaultRunFor:self selector:@selector(resultFromDescribe:) identifier:fName];
}

- (void) doDelete
{
	int isOK = NSRunAlertPanel (@"Delete", 
								@"Are you sure you want to delete label %s?", 
								@"OK", 
								@"Cancel", 
								nil,
								[fName cString]);

	if ( isOK )
	{
		[PerforceActionLabelDelete defaultRunFor:nil selector:nil identifier:fName];
	}
}

- (void) doSyncTo
{
	NSMutableString* syncPath = [NSMutableString stringWithString:@"@"];
	
	[syncPath appendString:fName];
	
	[PerforceActionSync defaultRun:nil revision:syncPath];	
}

- (void) resultFromDescribe:(PerforceActionLabelGet*)action
{
	if ( [action wasSuccess] )
	{
		NSMutableString* titleString = [NSMutableString stringWithString:@"Description of Label "];
		
		[titleString appendString:[action getIdentifier]];
		
		[ReadOnlyEditorController showWindowWith:[action getOutput] title:titleString];
	}
}


@end
